Description: North Dakota Supreme Court Opinions by month

June 2012
June 13, 2012
Kosobud v. Kosobud, 2012 ND 122
Assets accumulated after separation but prior to divorce are included in the marital estate.
The sporadic nature of the parties' marriage is a valid consideration for a court in making an equitable division of property.
Marital property valuations are not clearly erroneous if they are within the range of evidence presented.
When the exact dates of retirement and the resulting income reductions following retirement are unknown, a court may order permanent spousal support despite the obligor's approaching retirement.
When a motion for new trial is made in the district court, the moving party is limited on appeal to a review of the grounds presented to the district court.
June 12, 2012
Skachenko v. Skachenko, 2012 ND 121
A district court does not abuse its discretion when it denies a party's motion to use frozen marital funds to conduct a business evaluation when the moving party has access to non-frozen, separate funds and has not addressed why the non-frozen, separate funds cannot be used.
A district court does not abuse its discretion when it denies a post-trial motion to include, as a separate asset of the marital estate, a loan owed by a party's business to the party when the loan was not included on the property and debt listing filed with the court and was not at issue prior to or during trial.
A district court has discretion to award attorney fees as a sanction for misconduct during litigation and must make findings regarding culpability of the party against whom sanctions are being imposed, prejudice against the moving party, and the availability of less severe alternative sanctions.
June 7, 2012
Dakota Resource Council v. Stark County Board of County Commissioners, 2012 ND 114
A nonprofit organization that has not suffered an injury itself can sue as the representative of its members if: (1) its members would otherwise have standing to sue in their own right; (2) the interests it seeks to protect are germane to the organization; and (3) neither the claim asserted nor the relief requested requires the participation of individual members in the lawsuit.
Although interpretation of an ordinance presents a question of law fully reviewable on appeal, the interpretation of a zoning ordinance by a governmental entity is a quasi-judicial act, and a reviewing court should give deference to the judgment and interpretation of the governing body rather than substitute its judgment for that of the enacting body.
Disciplinary Board v. Summers, 2012 ND 116
The Supreme Court reviews disciplinary proceedings de novo.
Disciplinary Board v. Dyer, 2012 ND 118
Evidence that the balance of a trust account fell below the total amount held in trust supports a finding that the lawyer violated N.D.R. Prof. Conduct 1.15.
A lawyer is permitted to disclose information related to the representation of a client when the lawyer is defending himself or herself in any proceeding concerning the lawyer's representation of the client, including disciplinary proceedings initiated by a third party.
A lawyer is required to comply with a hearing panel's order to disclose information related to the representation of a client during a disciplinary proceeding after the lawyer asserts all nonfrivolous claims to protect the confidential information.
Duffy v. State, 2012 ND 111
Order denying a petitioner's application for post-conviction relief on the basis of ineffective assistance of counsel is summarily affirmed under N.D.R.App.P. 35.1(a)(2).
Empower the Taxpayer v. Cory Fong, 2012 ND 119
There is no private right of action to enforce the provisions of the Corrupt Practices Act.
Gress v. State, 2012 ND 108
Order dismissing application for post-conviction relief is summarily affirmed under N.D.R.App.P. 35.1(a)(6) and (7).
Hangsleben v. Halverson, 2012 ND 106
Summary judgment and award of costs and attorney's fees are summarily affirmed under N.D.R.App.P. 35.1(a)(4) and (6).
Holbach v. City of Minot, 2012 ND 117
Municipal courts are not courts of record.
Post-conviction relief under N.D.C.C. ch. 29-32.1 is not available in municipal courts in North Dakota.
State v. Chacano, 2012 ND 113
The purpose of requiring the court's consent to dismissal under N.D.R.Crim.P. 48(a) is to prevent harassment of a defendant by charging, dismissing and recharging without placing a defendant in jeopardy.
Rule 48(a) applies to the dismissal of a criminal charge and does not require the prosecuting attorney to take any specific action before a charge dismissed without prejudice can be refiled.
State v. DeLeon, 2012 ND 112
Order revoking probation and resentencing defendant to prison is summarily affirmed under N.D.R.App.P. 35.1(a)(2).
State v. Nelson, 2012 ND 110
Order denying motion to dismiss an administrative lien placed on prisoner spending accounts is summarily affirmed under N.D.R.App.P. 35.1(a)(2) and (7).
State v. Schmidt, 2012 ND 120
A private party cannot be considered an agent of the State merely because a police officer requested surveillance video from him as part of the investigation.
A police officer's failure to collect evidence in the first instance is not a violation of Brady v. Maryland, 373 U.S. 83 (1963).
A defendant is not deprived of his right to confront a witness against him when the witness testified at trial and was subject to the defendant's cross-examination.
State v. Unruh, 2012 ND 107
A district court order revoking probation and an amended criminal judgment are summarily affirmed under N.D.R.App.P. 35.1(a)(7).
Thorson v. State, 2012 ND 109
Order dismissing application for post-conviction relief is summarily affirmed under N.D.R.App.P. 35.1(a)(2).
Working Capital #1 v. Quality Auto Body, 2012 ND 115
An eviction to recover possession of real estate is maintainable when a lessee holds over after the termination of the lease or expiration of the lessee's term.
N.D.C.C. 47-16-06 does not automatically renew a lease for up to one year when a tenant holds over and a landlord accepts a rent payment; rather, the section only raises a disputable presumption that the lease was renewed on the same terms.
Issues or arguments not raised in the district court are generally not considered on appeal.